==> tine20-exampleapplication_2016.11.24.tar.bz2: ExampleApplication/js/ExampleApplication-lang-es-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 13:01+0000\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=n != 1;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Country: NOT SPECIFIED / ANY\nX-Poedit-Language: Spanish\nX-Poedit-SourceCharset: utf-8\n"

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "%s's personal example records"
: ""

, "Example Application test"
: ""

, "ExampleRecord"
: ""

, "Name"
: "Nombre"

, "Status"
: "Estado"

, "Title"
: "Título"

, "Budget"
: "Presupuesto"

, "Show closed"
: "Función Cerrada"

, "example record, example records"
: [
  ""
 ,""

]
, "example record list, example record lists"
: [
  ""
 ,""

]
, "Quick Search"
: "Búsqueda Rápida"

, "Last modified"
: ""

, "Last modifier"
: ""

, "Creation Time"
: ""

, "Creator"
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "ExampleApplication"
: "AplicaciónDeEjemplo"

, "ExampleRecords"
: "RegistrosDeEjemplo"

, "All ExampleRecords"
: "Todos los RegistrosDeEjemplo"

, "Description"
: "Descripción"

, "record list, record lists"
: [
  "listado de registro"
 ,"listado de registros"

]
, "example record"
: ""

, "example record list"
: ""

, "record list"
: "listado de registro"

}));

==> tine20-exampleapplication_2017.08.11.tar.bz2: ExampleApplication/js/ExampleApplication-lang-es-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 13:01+0000\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=n != 1;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Country: NOT SPECIFIED / ANY\nX-Poedit-Language: Spanish\nX-Poedit-SourceCharset: utf-8\n"

, "ExampleRecord"
: ""

, "Name"
: "Nombre"

, "Status"
: "Estado"

, "Reason"
: ""

, "Total Example Records"
: ""

, "New Example"
: ""

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Reasons Available"
: ""

, "Possible status reasons."
: ""

, "Change"
: ""

, "Documentation"
: ""

, "Requirement Changed"
: ""

, "Not Possible"
: ""

, "Implementation"
: ""

, "Review"
: ""

, "Integration"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Example String"
: ""

, "Just an example string for test purpose"
: ""

, "ExampleApplication"
: "AplicaciónDeEjemplo"

, "example record, example records"
: [
  ""
 ,""

]
, "example records"
: ""

, "example record list"
: ""

, "example record lists"
: ""

, "Number"
: ""

, "Default Example Record Container"
: ""

, "The default container for new records"
: ""









, "example record"
: ""

}));
